@@ -22,12 +22,15 @@ def esat(T):
     esat =  e1*10**(10.79586*(1-TK/T)-5.02808*logTTK+ 1.50474*1e-4*(1.-10**(-8.29692*(T/TK-1)))+ 0.42873*1e-3*(10**(4.76955*(1-TK/T))-1)-2.2195983) 
     return esat
 
-# conversion relative humidity to mixing ratio
 def rh2mixr(RH,p,T):
+    # purpose: conversion relative humidity (unitless) to mixing ratio [kg/kg]
     es = esat(T)
-    return Mw/Md*RH/100.*es/(p-RH/100.*es)*1000.
+    return Mw/Md*RH*es/(p-RH*es)
+
+def mixr2rh(mixr,p,T):
+    # purpose: conversion mixing ratio to relative humidity [kg/kg] (not tested)
+    return mixr * p/((mixr+Mw/Md)*esat(T))
 
-# conversion mixing ratio to specific humidity (always kg/kg)
 def mixr2sh(W):
     '''conversion from mixing ratio (units [kg/kg]) to specific humidity (units also [kg/kg])
     '''
