@@ -1,7 +1,7 @@
 from numpy import log, nan, sign, pi, sqrt, arctan
 
 g = 9.81 # gravitational aCCelleration ms^-2
-krm = 0.40 # von Kàrmàn constant
+krm = 0.40 # von Karman constant
 
 
 # constants for the flux-profile relationships
